/*
  Macro           Test_CopyBlock
  Author          Carlo Hogeveen
  Website         eCarlo.nl/tse
  Compatibility   TSE v4 upwards
  Version         v1   19 Jan 2025

  This test macro demonstrates that CopyBlock() does not show its progress
  percentage when called from within the _AFTER_NONEDIT_COMMAND_ hook.

  It does so by temporarily creating two buffers, fill one buffer with an
  extreme amount of text, and then testing a CopyBlock() from one buffer to the
  other. Afterwards it cleans up both temporary buffers.

  In the list:
    <Escape> exits the list.
    Any other key does a CopyBlock() from the hook without showing progress.
*/


integer lst_id = 0
integer tmp_id = 0


proc after_nonedit_command()
  integer old_MsgLevel = Set(MsgLevel, _ALL_MESSAGES_)

  if  GetBufferId() == lst_id
  and Query(Key)    <> <Escape>
    KeyPressed()
    Message('CopyBlock() progress is NOT shown from inside the hook ... ')
    Delay(36)
    EmptyBuffer(lst_id)
    GotoBufferId(tmp_id)
    MarkLine(1, NumLines())
    GotoBufferId(lst_id)
    CopyBlock()
    BegFile()
  endif

  Set(MsgLevel, old_MsgLevel)
end after_nonedit_command


proc Main()
  integer column                    = 0
  integer i                         = 0
  integer line                      = 0
  integer old_id                    = GetBufferId()
  integer old_InsertLineBlocksAbove = Set(InsertLineBlocksAbove, OFF)
  integer old_MsgLevel              = Set(MsgLevel, _NONE_)
  integer old_UnMarkAfterPaste      = Set(UnMarkAfterPaste, ON)

  Message('Prepping ... ')
  tmp_id = NewFile()
  SetUndoOff()
  for line = 1 to 1000
    AddLine()
    BegLine()
    for column = 1 to 1000
      InsertText(Chr(Random(65, 90)))
    endfor
  endfor
  MarkLine(1, NumLines())
  for i = 1 to (1000 - 1)
    CopyBlock()
  endfor

  Set(MsgLevel, _ALL_MESSAGES_)

  KeyPressed()
  Message('CopyBlock() progress will be shown outside the hook ... ')
  Delay(36)
  MarkLine(1, NumLines())
  lst_id = CreateTempBuffer()
  CopyBlock()

  Hook(_AFTER_NONEDIT_COMMAND_, after_nonedit_command)
  List('Dummy list', 80)
  UnHook(after_nonedit_command)

  KeyPressed()
  Message('The end.')
  GotoBufferId(old_id)
  AbandonFile(tmp_id)
  AbandonFile(lst_id)
  Set(InsertLineBlocksAbove, old_InsertLineBlocksAbove)
  Set(MsgLevel             , old_MsgLevel             )
  Set(UnMarkAfterPaste     , old_UnMarkAfterPaste     )
  PurgeMacro(CurrMacroFilename())
end Main

